@@ -94,11 +94,11 @@ import typing_extensions
 
 from ._jsii import *
 
-import aws_cdk.core
+import constructs
 
 
 class EcrImageScanNotify(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-ecr-image-scan-notify.EcrImageScanNotify",
 ):
@@ -108,7 +108,7 @@ class EcrImageScanNotify(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
         webhook_url: builtins.str,
