@@ -8,18 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.assertions._jsii
-import aws_cdk.aws_events._jsii
-import aws_cdk.aws_events_targets._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-ecr-image-scan-notify",
-    "0.0.395",
+    "1.0.0",
     __name__[0:-6],
-    "cdk-ecr-image-scan-notify@0.0.395.jsii.tgz",
+    "cdk-ecr-image-scan-notify@1.0.0.jsii.tgz",
 )
 
 __all__ = [
